
import { createRoot } from 'react-dom/client';
import { StrictMode } from 'react';
import App from './App.tsx';
import './index.css';

// Declare the custom window property to fix TypeScript error
declare global {
  interface Window {
    appInitialized?: boolean;
    hasAttemptedReload?: boolean;
  }
}

// Function to safely initialize our app
function initializeApp() {
  try {
    console.log("Initializing application...");
    
    // Get or create root element
    let rootElement = document.getElementById("root");
    
    if (!rootElement) {
      console.warn("Root element not found, creating one");
      rootElement = document.createElement("div");
      rootElement.id = "root";
      document.body.appendChild(rootElement);
    }
    
    // Check if root already has content (to avoid double-rendering)
    if (rootElement.childNodes.length > 0) {
      console.warn("Root element already has content, skipping render");
      return;
    }
    
    // Create root and render
    const root = createRoot(rootElement);
    root.render(
      <StrictMode>
        <App />
      </StrictMode>
    );
    
    console.log("Application rendering started");
    
    // Set a flag to indicate successful initialization
    window.appInitialized = true;
  } catch (error) {
    console.error("Critical error during app initialization:", error);
    
    // Display error on page
    const errorElement = document.createElement("div");
    errorElement.style.cssText = "position:fixed;top:0;left:0;right:0;bottom:0;background:#111;color:white;padding:20px;font-family:sans-serif;z-index:9999;";
    errorElement.innerHTML = `
      <h1 style="color:#f44;">Application Error</h1>
      <p>The application failed to initialize. Please try refreshing the page.</p>
      <pre style="background:#222;padding:10px;overflow:auto;">${error instanceof Error ? error.message : String(error)}</pre>
      <button onclick="window.location.reload()" style="padding:8px 16px;background:#2563eb;color:white;border:none;border-radius:4px;cursor:pointer;margin-top:20px;">Reload Page</button>
    `;
    
    document.body.appendChild(errorElement);
  }
}

// Execute initialization with a slight delay to ensure DOM is fully loaded
if (document.readyState === "loading") {
  document.addEventListener("DOMContentLoaded", () => setTimeout(initializeApp, 100));
} else {
  setTimeout(initializeApp, 100);
}
